@@ -211,13 +211,10 @@ class Model():
         db = name_list[0]
         table = name_list[1]
         
-        #self.datetime_property
-        
         self.conn = pymongo.MongoClient(self.pymongo_connection)
         self.db_name = self.conn[db]
         self.db_name_table_name = self.db_name[table]
 
-
         data_old = self.db_name_table_name.find({name:value})
         data_old = [i for i in data_old]
 
@@ -230,10 +227,6 @@ class Model():
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[0][i[0]]
         
-        print 'new_value'
-        print new_value
-        print 'new_value'
-        
         data = self.db_name_table_name.update({name:value},{"$set":new_value})
         return data#返回ture 布尔值
 
@@ -258,10 +251,6 @@ class Model():
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[i[0]]
 
-        print 'new_value'
-        print new_value
-        print 'new_value'
-
         data = self.db_name_table_name.update({"_id":ObjectId(value)},{"$set":new_value})
         return data#返回ture 布尔值
 
